@@ -317,7 +317,7 @@ def __undergo_variation_operator(var_op : dict, offspring : Node,
   crossovers, mutations, coeff_opts,
   donor, internal_nodes, leaf_nodes) -> Node:
   # decide whether to actually do something
-  if var_op["rate"] > randu():
+  if var_op["rate"] < randu():
     # nope
     return offspring
 
@@ -347,4 +347,4 @@ def __check_tree_meets_all_constraints(tree : Node, constraints : dict=dict()) -
         break
     else:
       raise ValueError("Unrecognized constraint name: {}".format(constraint_name))
-  return meets
\ No newline at end of file
+  return meets
